summaryrefslogtreecommitdiffstats
path: root/korganizer/kotodoeditor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kotodoeditor.cpp')
-rw-r--r--korganizer/kotodoeditor.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/korganizer/kotodoeditor.cpp b/korganizer/kotodoeditor.cpp
index 8da491fb..c3eee2ee 100644
--- a/korganizer/kotodoeditor.cpp
+++ b/korganizer/kotodoeditor.cpp
@@ -51,8 +51,8 @@
#include "kotodoeditor.h"
#include "kocore.h"
-KOTodoEditor::KOTodoEditor( Calendar *calendar, TQWidget *tqparent ) :
- KOIncidenceEditor( TQString(), calendar, tqparent ),
+KOTodoEditor::KOTodoEditor( Calendar *calendar, TQWidget *parent ) :
+ KOIncidenceEditor( TQString(), calendar, parent ),
mTodo( 0 ), mCalendar( 0 ), mRelatedTodo( 0 ), mGeneral( 0 ), mRecurrence( 0 )
{
}
@@ -257,7 +257,7 @@ void KOTodoEditor::setDates( const TQDateTime &due, bool allDay, Todo *relatedEv
{
mRelatedTodo = relatedEvent;
// inherit some properties from tqparent todo
if ( mRelatedTodo ) {
mGeneral->setCategories( mRelatedTodo->categories() );
}
@@ -306,7 +306,7 @@ void KOTodoEditor::writeTodo( Todo *todo )
}
writeDesignerFields( todo );
// set related incidence, i.e. tqparent to-do in this case.
if ( mRelatedTodo ) {
todo->setRelatedTo( mRelatedTodo );
}
@@ -257,7 +257,7 @@ void KOTodoEditor::setDates( const TQDateTime &due, bool allDay, Todo *relatedEv
{
mRelatedTodo = relatedEvent;
- // inherit some properties from tqparent todo
+ // inherit some properties from parent todo
if ( mRelatedTodo ) {
mGeneral->setCategories( mRelatedTodo->categories() );
@@ -306,7 +306,7 @@ void KOTodoEditor::writeTodo( Todo *todo )
}
writeDesignerFields( todo );
- // set related incidence, i.e. tqparent to-do in this case.
+ // set related incidence, i.e. parent to-do in this case.
if ( mRelatedTodo ) {
todo->setRelatedTo( mRelatedTodo );